@@ -25,13 +25,16 @@
  * HISTORY
  *
  *	$Log: IOFWDCLProgram.cpp,v $
- *	Revision 1.24.10.3  2005/03/08 03:48:47  collin
+ *	Revision 1.28  2005/03/12 03:27:51  collin
  *	*** empty log message ***
  *	
- *	Revision 1.24.10.2  2004/09/14 00:43:29  niels
+ *	Revision 1.27  2004/06/19 01:05:50  niels
+ *	turn on prebinding for IOFireWireLib.plugin
+ *	
+ *	Revision 1.26  2004/06/10 20:57:36  niels
  *	*** empty log message ***
  *	
- *	Revision 1.24.10.1  2004/09/13 21:10:10  niels
+ *	Revision 1.25  2004/04/22 23:34:11  niels
  *	*** empty log message ***
  *	
  *	Revision 1.24  2003/12/19 22:07:46  niels
@@ -73,7 +76,7 @@
 OSDefineMetaClass( IODCLProgram, OSObject )
 OSDefineAbstractStructors ( IODCLProgram, OSObject )
 OSMetaClassDefineReservedUsed ( IODCLProgram, 0 ) ;
-OSMetaClassDefineReservedUnused ( IODCLProgram, 1 ) ;
+OSMetaClassDefineReservedUsed ( IODCLProgram, 1 ) ;
 OSMetaClassDefineReservedUnused ( IODCLProgram, 2 ) ;
 OSMetaClassDefineReservedUnused ( IODCLProgram, 3 ) ;
 OSMetaClassDefineReservedUnused ( IODCLProgram, 4 ) ;
@@ -244,7 +247,7 @@ IODCLProgram :: init ( IOFireWireBus :: DCLTaskInfo * info)
 				case 1 :
 				case 2 :
 				{
-					fBufferMem = info->auxInfo->u.v1.bufferMemoryMap ;	// handles version 2 also
+					fBufferMem = info->auxInfo->u.v1.bufferMemoryMap ; // handles version 2 also
 					if ( fBufferMem )
 					{
 						fBufferMem->retain() ;
@@ -252,7 +255,6 @@ IODCLProgram :: init ( IOFireWireBus :: DCLTaskInfo * info)
 					
 					break ;
 				}
-				
 				default :
 					ErrorLog( "unsupported version found in info->auxInfo!\n" ) ;
 					success = false ;
@@ -317,20 +319,3 @@ IODCLProgram :: getBufferMap() const
 {
 	return fBufferMem ;
 }
-
-void
-IODCLProgram :: closeGate()
-{
-}
-
-void
-IODCLProgram :: openGate()
-{
-}
-
-IOReturn
-IODCLProgram :: synchronizeWithIO()
-{
-	return kIOReturnSuccess ;
-}
-
