@@ -150,3 +150,26 @@ void IOFireWireLink::disablePHYPortOnSleep( UInt32 mask )
 {
 	// nothing to do
 }
+
+UInt32 * IOFireWireLink::getPingTimes ()
+{
+	return NULL ;
+}
+
+bool IOFireWireLink::getPingTransmits ()
+{
+	return false ;
+}
+
+void IOFireWireLink::setPingTransmits ( bool ping )
+{
+	// nothing to do
+}
+
+IOReturn IOFireWireLink::handleAsyncCompletion( IOFWCommand *cmd, IOReturn status )
+{
+	// nothing to do
+	
+	return kIOReturnSuccess;
+}
+
