@@ -25,6 +25,9 @@
  */
 /*
 	$Log: IOFireWireLocalNode.cpp,v $
+	Revision 1.8  2005/02/18 22:56:53  gecko1
+	3958781 Q45C EVT: FireWire ASP reporter says port speed is 800 Mb/sec
+	
 	Revision 1.7  2003/10/16 00:57:20  collin
 	*** empty log message ***
 	
@@ -148,7 +151,7 @@ bool IOFireWireLocalNode::attach(IOService * provider )
 //
 
 void IOFireWireLocalNode::setNodeProperties(UInt32 gen, UInt16 nodeID,
-                                        UInt32 *selfIDs, int numSelfIDs)
+                                        UInt32 *selfIDs, int numSelfIDs, IOFWSpeed maxSpeed )
 {
     OSObject *prop;
     
@@ -164,7 +167,7 @@ void IOFireWireLocalNode::setNodeProperties(UInt32 gen, UInt16 nodeID,
     setProperty(gFireWireSelfIDs, prop);
     prop->release();
 
-    prop = OSNumber::withNumber((selfIDs[0] & kFWSelfID0SP) >> kFWSelfID0SPPhase, 32);
+    prop = OSNumber::withNumber(maxSpeed, 32);
     setProperty(gFireWireSpeed, prop);
     prop->release();
 }
