@@ -82,6 +82,7 @@ class IOFireWireUnit : public IOFireWireNub
     OSDeclareDefaultStructors(IOFireWireUnit)
 
 	friend class IOFireWireUnitAux;
+	friend class IOFireWireDevice;
 
 protected:
     IOFireWireDevice *fDevice;	// The device unit is part of
@@ -131,6 +132,8 @@ public:
 	virtual void clearNodeFlags( UInt32 flags );
     virtual UInt32 getNodeFlags( void );
 
+	virtual IOReturn setConfigDirectory( IOConfigDirectory *directory );
+
     /*
      * Create local FireWire address spaces for the device to access
      */
@@ -144,6 +147,10 @@ protected:
 
 public:
 	void setMaxSpeed( IOFWSpeed speed );
+
+protected:
+	void terminateUnit( void );
+	static void terminateUnitThreadFunc( void * refcon );
 	    
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireUnit, 0);
