@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -28,6 +25,12 @@
  * HISTORY
  *
  * $Log: IOFireWireUserClient.h,v $
+ * Revision 1.45  2004/01/22 01:49:59  niels
+ * fix user space physical address space getPhysicalSegments
+ *
+ * Revision 1.44  2003/12/19 22:07:46  niels
+ * send force stop when channel dies/system sleeps
+ *
  * Revision 1.43  2003/11/07 21:24:28  niels
  * *** empty log message ***
  *
@@ -347,7 +350,9 @@ class IOFireWireUserClient : public IOUserClient
 #pragma mark -
 		// physical address space stuff
 		IOReturn						physicalAddressSpace_Create ( 
-												PhysicalAddressSpaceCreateParams * 	params,
+												UInt32						size,
+												void *						backingStore,
+												UInt32						flags,
 												UserObjectHandle * 			outKernAddrSpaceRef ) ;
 		IOReturn						physicalAddressSpace_GetSegments (
 												UserObjectHandle			addressSpaceHandle,
@@ -462,10 +467,13 @@ class IOFireWireUserClient : public IOUserClient
 														UInt32 *					outChanSupportedLo ) const ;
 		IOReturn						localIsochPort_Create ( 
 														LocalIsochPortAllocateParams * params, 
-														UserObjectHandle *		portRef ) ;
+														UserObjectHandle *			portRef ) ;
+		IOReturn						localIsochPort_SetChannel (
+														UserObjectHandle			portHandle,
+														UserObjectHandle			channelHandle ) ;
 		IOReturn						setAsyncRef_DCLCallProc ( 
-														OSAsyncReference 		asyncRef, 
-														UserObjectHandle 		portRef ) ;
+														OSAsyncReference			asyncRef, 
+														UserObjectHandle			portRef ) ;
 		
 #pragma mark -
 		// isoch channel
